@@ -48,7 +48,7 @@ def confirm_cwd():
 )
 @click.pass_context
 def main(ctx, project, timeout):
-    Package("suite_py", verbose=True).smartupgrade()
+    Package("suite_py").upgrade()
     print(f"v{__version__}")
     project_name = os.path.basename(project)
     ctx.ensure_object(dict)
