@@ -101,8 +101,9 @@ def create_release(repo, new_version, message, project):
     if new_release:
         logger.info(f"La release è stata creata! Link: {new_release.html_url}")
 
-        drone_url = drone.get_last_build_url(project)
-        if drone_url:
+        build_number = drone.get_build_from_tag(project, new_version)
+        if build_number:
+            drone_url = drone.get_build_url(project, build_number)
             logger.info(f"Puoi seguire il deploy in produzione su {drone_url}")
 
 
