@@ -48,6 +48,14 @@ class CaptainHook(metaclass=Singleton):
     def get_users_list(self):
         return self.send_get_request("/users/all")
 
+    def rollback(self, project, version):
+        data = {
+            "project": project,
+            "user": git.get_username(),
+            "version": version,
+        }
+        return self.send_post_request("/projects/rollback", data)
+
     def send_post_request(self, endpoint, data):
         try:
             return requests.post(
