@@ -23,9 +23,9 @@ class GithubHandler(metaclass=Singleton):
     def get_user(self):
         return self._client.get_user()
 
-    def create_pr(self, repo, branch, title, body="", base="master"):
+    def create_pr(self, repo, branch, title, body="", base="master", is_draft=False):
         return self.get_repo(repo).create_pull(
-            title=title, head=branch, base=base, body=body
+            title=title, head=branch, base=base, body=body, draft=is_draft
         )
 
     def get_pr(self, repo, pr_number):
