@@ -6,7 +6,7 @@ from PyInquirer import prompt
 
 from suite_py.lib.singleton import Singleton
 
-TOKENS = ["github", "youtrack", "slack", "drone"]
+TOKENS = ["github", "youtrack", "drone"]
 
 
 class Tokens(metaclass=Singleton):
@@ -58,10 +58,6 @@ class Tokens(metaclass=Singleton):
     def youtrack(self):
         return self._tokens["youtrack"]
 
-    @property
-    def slack(self):
-        return self._tokens["slack"]
-
     @property
     def drone(self):
         return self._tokens["drone"]
